@@ -1,4 +1,4 @@
-require 'rake/file_creation_task'
+require "rake/file_creation_task"
 
 module Capistrano
   class UploadTask < Rake::FileCreationTask
